---
name: Bug report
about: Create a report to help us improve mitiq
title: ''
labels: bug
assignees: ''

---

Pre-Report Checklist
--------------------

- [ ] I am running the latest version of mitiq
- [ ] I checked to make sure that this bug has not already been reported

Issue Description
-----------------

Insert a short description of the bug here, along with what you expected the behavior to be.

Thanks for helping us improve mitiq! 🙂

How to Reproduce
----------------

If useful, provide a numbered list of the steps that result in the error.

Otherwise, just fill out the "Code Snippet" and "Error Output" sections below.

### Code Snippet

```python
Include a snippet of the mitiq code that produces the error here.
```

### Error Output

```
Additionally, please copy and paste the output of the above code here.
```

Environment Context
-------------------

Use the `about()` function to summarize information on operating system, python version and dependencies.
```python
from mitiq import about
about()
```

Additional Python Environment Details (`pip freeze` or `conda list`):

```
Copy and paste the output of `pip freeze` or `conda list` here.
```
